/*

Code to graph boxplot over time of the level of the minimum wage and 
the distribution of changes (excluding zeros).

*/

clear all
set more off
set scheme s1color

cd "G:\Deptdata\Research\Share\RE-MJL-B\Minimum Wage Project\paper\FINAL\"

use data\CPIMSA_panel_pctchmw_newLW_NewBartik_mar12.dta, clear

**merge in annual federal minimum wage 
merge m:1 year using data\fedmin_yearly.dta, keepusing(fedmin)
drop if _merge != 3
drop _merge


** pctch_avgmw is our wage measure - only include nonzero values when doing the dispersion graph (boxplot over time)
** msa_avgmw will be the levels variable


** Make variables for boxplots:

** levels
sort year
by year : egen mw = mean(avgmw)
by year : egen medw = median(avgmw)
by year : egen p75w = pctile(avgmw), p(75)
by year : egen p25w = pctile(avgmw), p(25)
by year : egen minw = min(avgmw)
by year : egen maxw = max(avgmw)

** pct change variables

by year : egen mpct = mean(pctch_avgmw) if pctch_avgmw != 0
by year : egen medpct = median(pctch_avgmw) if pctch_avgmw != 0
by year : egen p75pct = pctile(pctch_avgmw) if pctch_avgmw != 0, p(75)
by year : egen p25pct = pctile(pctch_avgmw) if pctch_avgmw != 0, p(25)
by year : egen minpct = min(pctch_avgmw) if pctch_avgmw != 0
by year : egen maxpct = max(pctch_avgmw) if pctch_avgmw != 0

by year : egen mpctb = mean(pctch_avgmw) 
by year : egen medpctb = median(pctch_avgmw) 
by year : egen p75pctb = pctile(pctch_avgmw), p(75)
by year : egen p25pctb = pctile(pctch_avgmw) , p(25)
by year : egen minpctb = min(pctch_avgmw) 
by year : egen maxpctb = max(pctch_avgmw) 

*************************************************************************************
** Graphs

foreach v in w {

	local tw "Minimum Wage Distributions Over Time"
	local yw "U.S. Dollars"
	local tpct "Percent change in minimum wage: distributions over time"
	local ypct "Percent"
	
	* ylines
	local ylabw "1.50(1)12.5, format(%7.2f)"
	local ylw "1.5(1)12.5"
	local ylabpct "0(5)40,"
	local ylpct "0(5)40"
	
	* include federal minimum wage for levels graph
	local fedw "(line fedmin year if geocode == 11, lc(cranberry) lw(*2) lp(longdash))"
	
	** adjust legends
	local legw `"holes(1 2 3) order(4 "Mean Across CPI MSAs" 5 "Federal Minimum")"'
	local legpct `"holes(1 2 3) order(4 "Mean")"'
	
	** Add note
	local notew `"note("Note: The bars indicate the 25th, 50th, and 75th percentiles of the minimum wage across all" "28 CPI MSAs, and the whiskers indicate minimum and maximum values." "  " "Source: Minimum wage data come from Federal and State Departments of Labor and city" "governments", size(small))"'
	local notepct ""
	#delimit ; 
	
	tw
	(rcap max`v' min`v' year if year > 1971 & year < 2019, lc(navy))
	(rbar med`v' p25`v' year if year > 1971 & year < 2019, lc(navy) fc(ebblue*.7) barw(.6))
	(rbar p75`v' med`v' year if year >1971 & year < 2019, lc(navy) fc(ebblue*.7) barw(.6))
	(line m`v' year if year > 1971 & year < 2019, lc(black) lw(medthick))
	`fed`v''
	,
	plotr(lstyle(none)) xscale(noline) yscale(noline)
	title("`t`v''", size(medlarge))
	ytitle("`y`v''") ylab(`ylab`v'' labs(small) angle(horizontal) notick)
	yline(`yl`v'', lc(gs10) lw(vthin))
	xtitle("") tlab(1970(5)2020, labs(small) tl(*1.5) tp(i))
	legend(region(lstyle(none)) symx(*.5) r(1) size(small) `leg`v'')
	`note`v''
	;

	graph export latex\boxplot_`v'.pdf, replace;
	#delimit cr
	
}
