/*
Code to graph low-wage shares of CPI MSAs over time.
*/


clear all
set more off
set scheme s1color

cd "G:\Deptdata\Research\Share\RE-MJL-B\Minimum Wage Project\paper\FINAL\"

use  data\CPIMSA_panel_pctchmw_newLW_NewBartik_mar12.dta, clear

** All msas included
local ypct_lowwage110 "0(.1).6"
local yt_pct_lowwage110 "Share"
*drop if year < 1997
replace year = year -1 //(because the variable is share of lowwage in t-1) 

cd `resultdir'
foreach v in pct_lowwage110 {

bys year : egen max`v' = max(`v')
bys year : egen min`v' = min(`v')
bys year : egen m`v' = mean(`v')
bys year : egen p75`v' = pctile(`v'), p(75)
bys year : egen p25`v' = pctile(`v'), p(25)
bys year : egen med`v' = median(`v')

//Graph all years
#delimit ;

tw
(rcap max`v' min`v' year if year > 1976 & year < 2018 , lc(dkgreen))
(rbar med`v' p25`v' year if  year > 1976 & year < 2018, lc(dkgreen) fc(green*.5) barw(.5))
(rbar p75`v' med`v' year if  year > 1976 & year < 2018, lc(dkgreen) fc(green*.5) barw(.5))
(line m`v' year if  year > 1976 & year < 2018 & geo == 1 , lc(black) lw(medthick))
,
plotregion(lstyle(none))
xscale(noline) yscale(noline)
title("", size(small))
xtitle("")
ytitle("`yt_`v''", size(small))
ylab(0(.05).4, labs(small) format(%3.2f) angle(horizontal) notick) 
yline(0(.05).4, lc(gs14) lw(medthin))
tlab(1975(5)2015, labs(small) tp(i) tl(*1.5))
legend(off)
note(" " "Note: The box and whiskers show the interquartile range, minimum, and maximum low-wage" "worker share across workers in a CPI MSA."
"  " "Source: Authors' calculations using the Current Population Survey (CPS).", size(small))
;

graph export latex\`v'_all.pdf, replace;

//Graph years starting from 1997;
tw
(rcap max`v' min`v' year if year >= 1997 & year < 2018 , lc(dkgreen))
(rbar med`v' p25`v' year if year>= 1997 & year < 2018, lc(dkgreen) fc(green*.5) barw(.5))
(rbar p75`v' med`v' year if year >= 1997 & year < 2018, lc(dkgreen) fc(green*.5) barw(.5))
(line m`v' year if year >= 1997 & year < 2018 & geo == 1 , lc(black) lw(medthick))

,
plotregion(lstyle(none))
xscale(noline) yscale(noline)
/*title("Over Time", size(medlarge))*/
xtitle("")
ytitle("`yt_`v''", size(medsmall))
ylab(0(.04).2, labs(small) format(%3.2f) angle(horizontal) notick)
yline(0(.04).2, lc(gs14) lw(medthin))
tlab(1997(2)2017, labs(small) tp(i) tl(*1.5))
legend(off)
note(" " "Note: The box and whiskers show the interquartile range, minimum, and maximum low-wage" "worker share across workers in a CPI MSA. The black line indicates the mean across 28 CPI" "MSAs"
"  " "Source: Authors' calculations using the Current Population Survey (CPS)."
, size(small))
;

graph export latex\`v'_all97.pdf, replace;
#delimit cr

}
