/**********************************************************************************

 Code to create CPI MSA regression tex files for PCE years for :
 all, all x energy, durables, nondurables, services, food, food away
 
***********************************************************************************/

clear all
set more off
set scheme s1color

cd "G:\Deptdata\Research\Share\RE-MJL-B\Minimum Wage Project\paper\FINAL\"

use data\CPIMSA_panel_pctchmw_newLW_NewBartik_mar12.dta, clear

replace pct_lowwage110 = pct_lowwage110*100
lab var pct_lowwage110 "Share of Low-Wage Workers (t-1)"
lab var pctch_avgmw "Pct. Chg. Min. Wage (t)"

tab year
count

//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Data Set up
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////


** Recode zero MSAepop to be missing
recode MSAepop 0 = .
lab var MSAepop "MSA EPOP"

** prep cpi data (make percent change variables: 1 year and 3 year)
foreach v of varlist cpi* {

	local lb : var lab `v'
	sort geocode year
	by geocode : gen pctch_`v' = 100*(`v'/l.`v' - 1)
	lab var pctch_`v' "`lb'"
	
}

********************************************************************************************************************************************
// Regressions: 

** Keep if years are the same for PCE sample (1997-2014)
drop if year < 1997
count
tab year

local cpiA "cpitot cpixe cpixfg cpidur cpindur cpiserv cpifh cpifah"
	
** Return to specification that includes the first lag of the MW change.  Report the cumulative effects. 
** Restrict years to same years available for PCE
foreach c in A  {
		
		// determin sample
		foreach y in `cpi`c'' {
		
			reg pctch_`y' pctch_avgmw l1.pctch_avgmw MSAempCh_bartik_restr i.year i.geocode , cluster(geocode) robust
			gen sample`y'1 = e(sample)
			local sample1 "`sample1'sample`y'1 "			
		}	
		
		egen sample`c'1 = rowmin(`sample1')

		foreach y in `cpi`c'' {
		
			///////////////////////////////////////////////////////////////////////////////////////////
			** Regression with restricted bartik employment growth metric (no lead)
			reg pctch_`y' pctch_avgmw l1.pctch_avgmw  MSAempCh_bartik_restr i.year i.geocode if sample`c'1 == 1, cluster(geocode) robust
			
			lincom pctch_avgmw + l1.pctch_avgmw 
			local 2years = r(estimate)
			local p = round(2*ttail(r(df), abs(r(estimate)/r(se))), .001)
			
			local scalnum "Persistent `2years' Pvalue `p' "
			
			eststo `y'1, addscalar(`scalnum')
			local est1 "`est1'`y'1 "
			
				
		}	
		
		#delimit ;

		esttab `est1' using latex\Table1.tex, replace depvars l se(%4.3f) b(%4.3f) ar2(%4.3f)
		starlevels(* .1 ** .05 *** .01) compress nonotes sfmt(%4.3f) scalars("Persistent Two-year MW Effect$^{\dagger}$ " "Pvalue P-Value") 
		keep(*pctch_avgmw *MSAempCh_bartik_restr) order(pctch_avgmw l_pctch f_pctch Persistent Pvalue) msign(--) 		
		prehead("\begin{table}\centering" "\caption{Baseline: Minimum Wage Changes and Inflation}" "\scalebox{0.8}" "{" "\label{base_pi}" "\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}" " \begin{tabular}{l*{8}{c}}" "\hline\hline ") 
		posthead("\hline" "\\") 
		prefoot("\hline") 
		postfoot("\hline\hline" "\end{tabular}" "}" "\parbox[1]{6.5in}{\footnotesize"
		"\textit{Notes:} The estimates are based on the baseline equation $ \Delta x^k_{i,t}=\alpha_i +\nu_t +\sum_{j=0}^{1} \beta(j) \Delta w_{i,t-j}+ \eta y_{i,t} + e_{i,t}, $"
		"where the dependent variable is inflation (price growth) for the CPI category indicated at the top of each column. The annual data cover 1999--2017. 
		 The estimates include location (CPI MSA) fixed effects as well as year effects.  The percent change in the minimum wage when a CPI MSA spans different states is calculated based 
		 on the average (population-weighted) minimum wage in each location and year as discussed in the text. $^{\dagger}$
		 Cumulative effect of the minimum wage change measured over two years (sum of contemporaneous and lagged effects).
		  Standard errors clustered by CPI MSA are in parentheses:  * p$<$0.10, ** p$<$0.05, *** p$<$0.01.}" "\end{table}") 
  		  substitute("\_" "_");
		

		#delimit cr
		capture eststo clear
		local est1 ""
}

