
/**********************************************************************************

 Code to create CPI MSA regression tex files for PCE years for :
 Total PCE, Core PCE, durables, nondurables, services, food, food away
 
***********************************************************************************/

clear all
set more off

cd "G:\Deptdata\Research\Share\RE-MJL-B\Minimum Wage Project\paper\FINAL\"

use data\CPIMSA_panel_pctchmw_consumption_NewBartik_mar12.dta, clear

drop if year < 1997 

drop if msaname == "Phoenix-Mesa" & year < 2002
lab var pctchpcgnf "Food home"
lab var pctch_avgmw "Pct. Chg. Min. Wage (t)"

**********************************************************************************************************
** Regressions on nominal consumption growth
 
local consA "pce pcecore pcgd pcgn pcsh pcgnf pcshf"


*PCE, DUR, ND, SERV, food home, food away
xtset geocode year

foreach c in A {
	
	foreach v in `cons`c'' {
			
			** determine samples (no lead)
			reg pctch`v' pctch_avgmw l.pctch_avgmw MSAempCh_bartik_restr i.year i.geocode, cluster(geocode)
			gen sample1`v' = e(sample)
			local sample1 "`sample1'sample1`v' "
	
	}
	
	egen sample`c'1 = rowmin(`sample1')

	
	foreach v in `cons`c'' {
			
			**Regression
			reg pctch`v' pctch_avgmw l.pctch_avgmw MSAempCh_bartik_restr i.year i.geocode if sample`c'1 == 1, cluster(geocode)
			
			lincom pctch_avgmw + l1.pctch_avgmw 
			local 2years = r(estimate)
			local secum2 = r(se)
			local p = round(2*ttail(r(df), abs(r(estimate)/r(se))), .001)
			
			local scalnum "Persistent `2years' Pvalue `p' "
			
			eststo `v'1, addscalar(`scalnum')
			local estname1 "`estname1'`v'1 "
			
	}
		
		#delimit ;

		
		esttab `estname1' using latex\Table2.tex, replace depvars l se(%4.3f) b(%4.3f) ar2(%4.3f) 
		starlevels(* .1 ** .05 *** .01) compress nonotes sfmt(%4.3f) scalars("Persistent Two-year MW Effect$^{\dagger}$" "Pvalue P-Value") 
		keep(*pctch_avgmw *MSAempCh_bartik_restr) order(pctch_avgmw l_pctch f_pctch Persistent Pvalue) msign(--) 		
		prehead("\begin{table}\centering" "\caption{Minimum Wage Changes and Nominal Consumption Growth}" "\scalebox{0.83}" "{" "\label{base_pce}" "\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}" " \begin{tabular}{l*{8}{c}}" "\hline\hline ") 
		posthead("\hline" "\\") 
		prefoot("\hline") 
		postfoot("\hline\hline" "\end{tabular}" "}" "\parbox[1]{6.5in}{\footnotesize"
		"\textit{Notes:} The estimates are based on the baseline equation $ \Delta x^k_{i,t}=\alpha_i +\nu_t +\sum_{j=0}^{1} \beta(j) \Delta w_{i,t-j}+ \eta y_{i,t} + e_{i,t}, $"
		"where the dependent variable is the percent change in consumption growth for the expenditure category indicated at the top of each column. The annual data cover 1999--2017. 
		 Core PCE excludes food and energy consumption. The estimates include location (CPI MSA) fixed effects as well as year effects. 
		 The percent change in the minimum wage when a CPI MSA spans different states is calculated based on the average (population-weighted) minimum wage in each location and year as discussed in the text.
		 $^{\dagger}$ Cumulative effect of the minimum wage change measured over two years (sum of contemporaneous and lagged effects).
		  Standard errors clustered by CPI MSA are in parentheses:  * p$<$0.10, ** p$<$0.05, *** p$<$0.01.}" "\end{table}")
		  substitute("\_" "_");
		  
		  
		#delimit cr
	
		capture eststo clear
		local estname1 ""
		local sample1 ""
		
}
