 /* 
 
 Code to run regressions looking at the effect of the minimum wage on real consumption growth where real consumption growth
 is the growth of the pce series minus the growth in the corresponding cpi series.

 */

clear all
set more off


cd "G:\Deptdata\Research\Share\RE-MJL-B\Minimum Wage Project\paper\FINAL\"

use data\CPIMSA_panel_pctchmw_consumption_NewBartik_mar12.dta, clear


merge 1:1 msaname year using  data\CPIMSA_panel_pctchmw_NewLW_NewBartik_mar12.dta, keepusing(cpi*)
drop if _merge == 2
drop _merge
lab var pctch_avgmw "Pct. Chg. Min. Wage (t)"
*drop if year < 1997
//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
**  Data Set Up
xtset geocode year


** prep cpi data (make percent change variables: 1 year and 3 year)
foreach v of varlist cpi* {

	local lb : var lab `v'
	
	sort geocode year
	by geocode : gen pctch_`v' = 100*(`v'/l.`v' - 1)
	lab var pctch_`v' "`lb'"
	
}

drop if year <1997

bys geocode year : gen r_pctchpce = pctchpce - pctch_cpitot
lab var r_pctchpce "Real PCE"
bys geocode year : gen r_pctchpcecore = pctchpcecore - pctch_cpixfg
lab var r_pctchpcecore "Real Core PCE"
bys geocode year : gen r_pctchpcshf = pctchpcshf - pctch_cpifah
lab var r_pctchpcshf "Food away" 
bys geocode year : gen r_pctchpcgd = pctchpcgd - pctch_cpidur
lab var r_pctchpcgd "Dur"
bys geocode year : gen r_pctchpcsh = pctchpcsh - pctch_cpiserv
lab var r_pctchpcsh "Serv"
bys geocode year : gen r_pctchpcgnf = pctchpcgnf - pctch_cpifh
lab var r_pctchpcgnf "Food home"
foreach v in r_pctchpce r_pctchpcecor r_pctchpcshf r_pctchpcgd r_pctchpcsh r_pctchpcgnf {
	tabstat year if `v' != . , stat(min max)
}

/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
** Create het treatement effect
egen pct_lowwage110dm = std(pct_lowwage110)
	
gen het110= pctch_avgmw*pct_lowwage110dm
lab var het110 "Heterogenous Treatment Effect"



**********************************************************************************************************
** Regressions : Look at real consumption growth : pce growth - total cpi growth; same for durables, food away, core pce 

*PCE, DUR, ND, SERV, food home, food away
foreach v in r_pctchpce r_pctchpcecor r_pctchpcshf r_pctchpcgd r_pctchpcgnf r_pctchpcsh {
			
			** determine samples
			*1: no lead
			reg `v' pctch_avgmw l.pctch_avgmw MSAempCh_bartik_restr i.year i.geocode, cluster(geocode)
			gen sample1`v' = e(sample)
			local sample1 "`sample1'sample1`v' "
			
}
	
egen sample1 = rowmin(`sample1')
	
foreach v in r_pctchpce r_pctchpcecore r_pctchpcgd  r_pctchpcsh r_pctchpcgnf r_pctchpcshf {
		
		
		* Reg 1:
		reg `v' pctch_avgmw l1.pctch_avgmw  MSAempCh_bartik_restr i.year i.geocode if sample1 == 1, cluster(geocode)
		
		lincom pctch_avgmw + l1.pctch_avgmw 
		local 2years = r(estimate)
		local secum2 = r(se)
		local p = round(2*ttail(r(df), abs(r(estimate)/r(se))), .001)
		
		local scalnum "Persistent `2years' Pvalue `p' "
		
		eststo `v'1, addscalar(`scalnum')
		
		local estname1 "`estname1'`v'1 "
}
		
	#delimit ;

	
esttab `estname1' using latex\Table3.tex, replace depvars l se(%4.3f) b(%4.3f) ar2(%4.3f)
starlevels(* .1 ** .05 *** .01) compress nonotes sfmt(%4.3f) scalars("Persistent Two-year MW Effect$^{\dagger}$" "Pvalue P-Value") 
keep(*pctch_avgmw *MSAempCh_bartik_restr) order(pctch_avgmw l_pctch f_pctch Persistent Pvalue) msign(--) 		
prehead("\begin{table}\centering" "\caption{Minimum Wage Changes and Real Consumption Growth}" "\scalebox{0.85}" "{" "\label{base_rpce}" "\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}" " \begin{tabular}{l*{8}{c}}" "\hline\hline ") 
posthead("\hline" "\\") 
prefoot("\hline") 
postfoot("\hline\hline" "\end{tabular}" "}" "\parbox[1]{6.5in}{\footnotesize"
"\textit{Notes:} The estimates are based on the baseline equation $ \Delta x^k_{i,t}=\alpha_i +\nu_t +\sum_{j=0}^{1} \beta(j) \Delta w_{i,t-j}+ \eta y_{i,t} + e_{i,t}, $"
"where the dependent variable is the percent change in real consumption growth for the expenditure category indicated at the top of each column. The annual data cover 1999--2017. 
 Core PCE excludes food and energy consumption. The estimates include location (CPI MSA) fixed effects as well as year effects. 
The percent change in the minimum wage when a CPI MSA spans different states is calculated based on the average (population-weighted) minimum wage in each location and year as discussed in the text.
 $^{\dagger}$ Cumulative effect of the minimum wage change measured over two years (sum of contemporaneous and lagged effects).
 Standard errors clustered by CPI MSA are in parentheses:  * p$<$0.10, ** p$<$0.05, *** p$<$0.01.}" "\end{table}") 
 substitute("\_" "_");
 
		  
