/*

Code to create CPI MSA regression tex files while controlling for low wage workers (HTE) for PCE years for :
 all, all x energy, durables, nondurables, services, food, food away
 
*/

clear all
set more off
set scheme s1color

cd "G:\Deptdata\Research\Share\RE-MJL-B\Minimum Wage Project\paper\FINAL\"


use data\CPIMSA_panel_pctchmw_newLW_NewBartik_mar12.dta, clear


//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Data Set up
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////


** Recode zero MSAepop to be missing
recode MSAepop 0 = .
lab var MSAepop "MSA EPOP"
lab var pctch_avgmw "Pct. Chg. Min. Wage (t)"

** prep cpi data (make percent change variables: 1 year and 3 year)
foreach v of varlist cpi* {

	local lb : var lab `v'
	
	sort geocode year
	by geocode : gen pctch_`v' = 100*(`v'/l.`v' - 1)
	lab var pctch_`v' "`lb'"
	
}

replace pct_lowwage110 = pct_lowwage110*100

egen mean_lowwage = mean(pct_lowwage110) if year >= 1997 & year <= 2017
gen pct_lowwage110dm = pct_lowwage110 - mean_lowwage

egen mean_avgmw = mean(pctch_avgmw) if year >= 1997 & year <= 2017
gen pctch_avgmwdm = pctch_avgmw - mean_avgmw

gen het110= pctch_avgmwdm*pct_lowwage110dm

lab var het110 "Heterogenous Treatment Effect [HTE] (t)"

********************************************************************************************************************************************
// Regressions: 

** Keep if years are the same for PCE sample
drop if year < 1997 

local cpiA "cpitot cpixe cpixfg cpidur cpindur cpiserv cpifh cpifah"
	
foreach c in A {
	
		//determine sample
		foreach y in `cpi`c'' {
		
		
			reg pctch_`y' pctch_avgmw l1.pctch_avgmw pct_lowwage110dm het110 l.het110 MSAempCh_bartik_restr i.year i.geocode , cluster(geocode) robust
			gen sample`y'1 = e(sample)
			local sample1 "`sample1'sample`y'1 " 
			
		}	
		
		
		
		egen sample`c'1 = rowmin(`sample1')
	
		
		local est1 ""

		
		foreach y in `cpi`c'' {
			
			reg pctch_`y' pctch_avgmw l1.pctch_avgmw MSAempCh_bartik_restr pct_lowwage110dm het110 l.het110  i.year i.geocode if sample`c'1 == 1, cluster(geocode) robust
			
			lincom pctch_avgmw + l1.pctch_avgmw
			local 2years = r(estimate)
			local p = round(2*ttail(r(df), abs(r(estimate)/r(se))), .001)
			
			
			lincom het110 + l1.het110 
			local het2 = r(estimate)
			local phet2 = round(2*ttail(r(df), abs(r(estimate)/r(se))), .001)
			
		
			local scalnum "Persistent `2years' Pvalue `p' Persistent_HTE `het2' Pvalue_HTE `phet2'"
			eststo `y'1, addscalar(`scalnum')
			
			
			local est1 "`est1'`y'1 "
			
		}	
		
		#delimit ;
		
		
		
		esttab `est1' using latex\Table4a.tex, replace depvars l se(%4.3f) b(%4.3f) ar2(%4.3f)
		starlevels(* .1 ** .05 *** .01) compress nonotes sfmt(%4.3f) scalars("Persistent Two-year MW Effect$^{\dagger}$" "Pvalue P-Value" "Persistent_HTE Two-year HTE$^{\dagger}$" "Pvalue_HTE P-Value") 
		keep(pctch_avgmw het110 *MSAempCh_bartik_restr) order(pctch_avgmw het110 Persistent Pvalue) msign(--) 		
		prehead( "\scalebox{0.80}" "{" /*"\begin{table}\centering" "\caption{Robustness: Controlling for the Share of Low-Wage Workers}" \scalebox{0.75}" "{" "\label{robust4a}" "\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}"*/ " \begin{tabular}{l*{8}{c}}" 
		"\multicolumn{9}{c}{\large Panel A: Inflation Results} \\ \\" "\hline\hline ") 
		posthead("\hline" "\\") 
		prefoot("\hline") 
		postfoot("\hline\hline" "\end{tabular}" "}")
		substitute("\_" "_");
		
		#delimit cr

}
