/*

Code to create CPI MSA regression tex files while controlling for low wage workers (HTE) for PCE years for :
 PCE, Core PCE, durables, nondurables, services, food, food away
 
(nominal consumption growth)
*/


clear all
set more off

cd "G:\Deptdata\Research\Share\RE-MJL-B\Minimum Wage Project\paper\FINAL\"

use data\CPIMSA_panel_pctchmw_consumption_NewBartik_mar12.dta, clear


** Set up heterogenous treatment effect
replace pct_lowwage110 = pct_lowwage110*100

egen mean_lowwage = mean(pct_lowwage110) if year >= 1997 & year <= 2017
gen pct_lowwage110dm = pct_lowwage110 - mean_lowwage

egen mean_avgmw = mean(pctch_avgmw) if year >= 1997 & year <= 2017
gen pctch_avgmwdm = pctch_avgmw - mean_avgmw

gen het110= pctch_avgmwdm*pct_lowwage110dm

lab var het110 "Heterogenous Treatment Effect [HTE] (t)"

lab var pctchpcgnf "Food home"
lab var pctch_avgmw "Pct. Chg. Min. Wage (t)"

**********************************************************************************************************
** Regressions 

local consA "pce pcecore pcgd pcgn pcsh pcgnf pcshf "

*PCE, DUR, ND, SERV, food home, food away
drop if year < 1997 
drop if msaname == "Phoenix-Mesa" & year < 2002


foreach c in A {
	
	foreach v in `cons`c'' {
			
			** determin samples
			reg pctch`v' pctch_avgmw l.pctch_avgmw pct_lowwage110dm het110 l1.het110  MSAempCh_bartik_restr i.year i.geocode, cluster(geocode)
			gen sample1`v' = e(sample)
			local sample1 "`sample1'sample1`v' "
			
	}

	
		
		egen sample`c'1 = rowmin(`sample1')	
		
		local estname1 ""

	foreach v in `cons`c'' {
			
			
			reg pctch`v'  pctch_avgmw l1.pctch_avgmw MSAempCh_bartik_restr pct_lowwage110dm het110 l1.het110 i.year i.geocode if sample`c'1 == 1, cluster(geocode)
			
			lincom pctch_avgmw + l1.pctch_avgmw
			local 2years = r(estimate)
			local secum2 = r(se)
			local p = round(2*ttail(r(df), abs(r(estimate)/r(se))), .001)
						
			lincom het110 + l1.het110  
			local het2 = r(estimate)
			local phet2 = round(2*ttail(r(df), abs(r(estimate)/r(se))), .001)
			
			local scalnum "Persistent `2years' Pvalue `p' Persistent_HTE `het2' Pvalue_HTE `phet2' "
			eststo `v'1, addscalar(`scalnum')
			
			local estname1 "`estname1'`v'1 "

	}
		
		#delimit ;

		esttab `estname1' using latex\Table4b.tex, replace depvars l se(%4.3f) b(%4.3f) ar2(%4.3f)
		starlevels(* .1 ** .05 *** .01) compress nonotes sfmt(%4.3f) scalars("Persistent Two-year MW Effect$^{\dagger}$" "Pvalue P-Value" "Persistent_HTE Two-year HTE$^{\dagger}$" "Pvalue_HTE P-Value") 
		keep(pctch_avgmw het110 *MSAempCh_bartik_restr) order(pctch_avgmw het110 Persistent Pvalue) msign(--) 		
		prehead( "\scalebox{0.85}" "{" /*"\begin{table}\centering" "\caption{Robustness: Controlling for the Share of Low-Wage Workers}" "\scalebox{0.75}" "{" "\label{robust4a}" "\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}"*/ " \begin{tabular}{l*{7}{c}}" 
		"\multicolumn{8}{c}{\large Panel B: Consumption Growth Results} \\ \\" "\hline\hline ") 
		posthead("\hline" "\\") 
		prefoot("\hline") 
		postfoot("\hline\hline" "\end{tabular}" "}") 
		substitute("\_" "_");

		#delimit cr 
}

