/*

Code to create CPI MSA regression tex files while controlling for low wage workers (HTE) for PCE years for :
 PCE, Core PCE, durables, nondurables, services, food, food away
 
(real consumption growth where real consumption growth is the growth of the pce series minus the growth in the corresponding cpi series.)
*/


clear all
set more off

cd "G:\Deptdata\Research\Share\RE-MJL-B\Minimum Wage Project\paper\FINAL\"


use data\CPIMSA_panel_pctchmw_consumption_NewBartik_mar12.dta, clear


merge 1:1 msaname year using  data\CPIMSA_panel_pctchmw_NewLW_NewBartik_mar12.dta, keepusing(cpi*)
drop if _merge == 2
drop _merge

** Set up heterogenous treatment effect
replace pct_lowwage110 = pct_lowwage110*100

egen mean_lowwage = mean(pct_lowwage110) if year >= 1997 & year <= 2017
gen pct_lowwage110dm = pct_lowwage110 - mean_lowwage

egen mean_avgmw = mean(pctch_avgmw) if year >= 1997 & year <= 2017
gen pctch_avgmwdm = pctch_avgmw - mean_avgmw

gen het110= pctch_avgmwdm*pct_lowwage110dm

lab var het110 "Heterogenous Treatment Effect [HTE] (t)"	
lab var pct_lowwage110dm "Share of Low-Wage Workers (t-1)"

lab var pctch_avgmw "Pct. Chg. Min. Wage (t)"

//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
**  Data Set Up
xtset geocode year


** prep cpi data (make percent change variables: 1 year and 3 year)
foreach v of varlist cpi* {

	local lb : var lab `v'
	
	sort geocode year
	by geocode : gen pctch_`v' = 100*(`v'/l.`v' - 1)
	lab var pctch_`v' "`lb'"
	
}

drop if year <1997

bys geocode year : gen r_pctchpce = pctchpce - pctch_cpitot 
lab var r_pctchpce "Real PCE"
bys geocode year : gen r_pctchpcecore = pctchpcecore - pctch_cpixfg
lab var r_pctchpcecore "Real Core PCE"
bys geocode year : gen r_pctchpcshf = pctchpcshf - pctch_cpifah
lab var r_pctchpcshf "Food away" 
bys geocode year : gen r_pctchpcgd = pctchpcgd - pctch_cpidur
lab var r_pctchpcgd "Dur"
bys geocode year : gen r_pctchpcsh = pctchpcsh - pctch_cpiserv
lab var r_pctchpcsh "Serv"
bys geocode year : gen r_pctchpcgnf = pctchpcgnf - pctch_cpifh
lab var r_pctchpcgnf "Food home"
foreach v in r_pctchpce r_pctchpcecor r_pctchpcshf r_pctchpcgd r_pctchpcsh r_pctchpcgnf {
	tabstat year if `v' != . , stat(min max)
}

**********************************************************************************************************


drop if year < 1997 

	
	foreach v in r_pctchpce r_pctchpcecor r_pctchpcshf r_pctchpcgd r_pctchpcsh r_pctchpcgnf {
			 
			// determine samples
			reg `v' pctch_avgmw l.pctch_avgmw MSAempCh_bartik_restr pct_lowwage110dm het110 l.het110 i.year i.geocode, cluster(geocode)
			gen sample1`v' = e(sample)
			local sample1 "`sample1'sample1`v' "

	}

	
	egen sample1 = rowmin(`sample1') 

	
	foreach v in r_pctchpce r_pctchpcecore r_pctchpcgd  r_pctchpcsh  r_pctchpcgnf r_pctchpcshf {
	

		reg `v' pctch_avgmw l.pctch_avgmw MSAempCh_bartik_restr pct_lowwage110dm het110 l.het110 i.year i.geocode if sample1 == 1, cluster(geocode)
		
		lincom pctch_avgmw + l1.pctch_avgmw
		local 2years = r(estimate)
		local p = round(2*ttail(r(df), abs(r(estimate)/r(se))), .001)
		
		lincom het110 + l1.het110 
		local het2 = r(estimate)
		local phet2 = round(2*ttail(r(df), abs(r(estimate)/r(se))), .001)
		
		local scalnum "Persistent `2years' Pvalue `p' Persistent_HTE `het2' Pvalue_HTE `phet2' "
		eststo `v'1, addscalar(`scalnum')
		
		
		local est1 "`est1'`v'1 "
		
	}
		
		#delimit ;

		esttab `est1' using latex\Table4c.tex, replace depvars l se(%4.3f) b(%4.3f) ar2(%4.3f)
		starlevels(* .1 ** .05 *** .01) compress nonotes sfmt(%4.3f) scalars("Persistent Two-year MW Effect$^{\dagger}$" "Pvalue P-Value" "Persistent_HTE Two-year HTE$^{\dagger}$" "Pvalue_HTE P-Value") 
		keep(pctch_avgmw het110 *MSAempCh_bartik_restr) order(pctch_avgmw het110 Persistent Pvalue) msign(--) 		
		prehead( "\scalebox{0.85}" "{" /*"\begin{table}\centering" "\caption{Robustness: Controlling for the Share of Low-Wage Workers}" "\scalebox{0.75}" "{" "\label{robust4a}" "\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}"*/ " \begin{tabular}{l*{6}{c}}" 
		"\multicolumn{7}{c}{\large Panel C: Real Consumption Growth Results} \\ \\" "\hline\hline ") 
		posthead("\hline" "\\") 
		prefoot("\hline") 
		postfoot("\hline\hline" "\end{tabular}" "}" ) 
		substitute("\_" "_");


		#delimit cr
