/*

 Code to create CPI MSA regression on debt data (total, auto) for: 
 All, sub-prime (<660), young < 35, sub-prime & young

*/

clear
set more off

*cd "G:\Deptdata\Research\Share\RE-MJL-B\Minimum Wage Project\paper\FINAL\"


use data/mwchange_bartik_msa.dta, clear 
encode msaname, gen(geocode)
xtset geocode year

gen f_pctch_avgmw = f.pctch_avgmw
gen l_pctch_avgmw = l.pctch_avgmw
lab var pctch_avgmw "Pct. Chg. Min. Wage (t)"
lab var f_pctch_avgmw "Pct. Chg. Min. Wage (t+1)"
lab var l_pctch_avgmw "Pct. Chg. Min. Wage (t-1)"
keep if year >= 1999

merge 1:1 msaname year using data/debtchange_msa_yr.dta
drop if _merge != 3
drop _merge
order msa_merge, after(msaname)
order year, before(msaname)
lab var hpi "HPI"

gen bartik_sq = MSAempCh_bartik_restr^2
lab var bartik_sq "Bartik$^{2}$"

*********************************************************************************************
*Data set up
*********************************************************************************************


capture drop cpi*
drop *s620* *fin* *other*

ren *_w * //they are weighted county measures, but are at msa level now so don't need that name

local eqftotalsum "totalsum totalsum_s660 totalsum_young totalsum_spy"
local eqfautosum  "autosum autosum_s660 autosum_young autosum_spy"
local eqftotalmean "totalmean_nz totalmean_nz_s660 totalmean_nz_young totalmean_nz_spy"
local eqfautomean "automean_nz automean_nz_s660 automean_nz_young  automean_nz_spy"
local eqftotalpct "totalpct totalpct_s660 totalpct_young totalpct_spy"
local eqfautopct "autopct autopct_s660 autopct_young autopct_spy"
local eqftotalcount "totalcount totalcount_s660 totalcount_young totalcount_spy"
local eqfautocount "autocount autocount_s660 autocount_young autocount_spy"

lab var pctch_avgmw "Pct.\ Chg.\ Min.\ Wage (t)"
lab var f_pctch_avgmw "Pct.\ Chg.\ Min.\ Wage (t+1)"
lab var l_pctch_avgmw "Pct.\ Chg.\ Min.\ Wage (t-1)"
lab var MSAempCh_bartik_restr "Bartik Empl. Growth"

capture drop geocode
encode msaname, gen(geocode)

xtset geocode year

keep if year >= 2000

*********************************************************************************************
*Regression
*********************************************************************************************

local alist "total auto" // --> creates both Table 5 and Table 6 : total debt and auto debt

foreach c in `alist' {
foreach i in `eqf`c'sum' {

	*Regressions including restricted bartik measure (contemporaneous only)
	reg d_`i' pctch_avgmw l_pctch_avgmw MSAempCh_bartik_restr i.year i.geocode, cluster(geocode) robust
	gen s`i'1 = e(sample)
	local sample1 "`sample1's`i'1 "
	di "`sample1'"
	

	}

	egen sample`c's1 = rowmin(`sample1')

	foreach i in `eqf`c'sum' {
	
		reg d_`i' pctch_avgmw l_pctch_avgmw MSAempCh_bartik_restr i.year i.geocode if sample`c's1 == 1, cluster(geocode) robust
		lincom pctch_avgmw + l_pctch_avgmw
		local 2years = r(estimate)
		local p = round(2*ttail(r(df), abs(r(estimate)/r(se))), 0.001)
		
		local scalnum "Persistent `2years' Pvalue `p' "
		
		eststo `i'1, add(`scalnum')
		local est`c'1 "`est`c'1'`i'1 "

	}

		di "`est`c'1'"
		di "`est`c'1a'"
	
	#delimit;
	
		esttab `est`c'1' using latex/Table5_`c'.tex, replace depvars l se(%4.3f) b(%4.3f) ar2(%4.3f) starlevels(* 0.1 ** 0.05 *** 0.01) compress nonotes sfmt(%4.3f) 
		scalars("Persistent Two-year MW Effect$^{\dagger}$" "Pvalue P-Value") keep(*pctch_avgmw *MSAempCh_bartik_restr ) order(pctch_avgmw l_pctch* Persistent Pvalue)
		mtitle("All" "Sub660" "Young" "Sub-Prime and Young") msign(--) collabels(none)
		prehead("\begin{table}\centering" "\caption{`c' Debt and Minimum Wage Changes}" "\scalebox{0.85}" "{""\label{debt_`c'}" "\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}" " \begin{tabular}{l*{4}{c}}" "\hline\hline ") 
		posthead("\hline" "\\") 
		prefoot("\hline") 
		postfoot("\hline\hline" "\end{tabular}" "}" "\parbox[1]{6.6in}{\footnotesize"
		"\textit{Notes:} The estimates are based on the baseline equation $ \Delta x^k_{i,t}=\alpha_i +\nu_t +\sum_{j=0}^{1} \beta(j) \Delta w_{i,t-j}+ \eta y_{i,t} + e_{i,t}, $"
		"where the dependent variable is the percent change in total debt balances for the borrower group indicated  at the top of each column.  The annual data cover 2000--2017. 
		 The estimates include location (CPI MSA) fixed effects as well as year effects.  The percent change in the minimum wage when a CPI MSA spans different states is calculated based 
		 on the average (population-weighted) minimum wage in each location and year as discussed in the text. $^{\dagger}$ 
		 Cumulative effect of the minimum wage change measured over two years (sum of contemporaneous and lagged effects).
		  Standard errors clustered by CPI MSA are in parentheses:  * p$<$0.10, ** p$<$0.05, *** p$<$0.01.}" "\end{table}");
	
	#delimit cr
	
	capture eststo clear
	local est1 ""
	local est`c'1 ""

	}
