/*

 Code to create latex table with success rate in credit applications for:
 All, sub-prime (<660), young < 35, sub-prime & young

 Also includes the percent change of sub-prime borrowers 

*/


clear 
set more off

*cd "G:\Deptdata\Research\Share\RE-MJL-B\Minimum Wage Project\paper\FINAL\"


use data\successrate_msaagg_1999_2017.dta, clear
ds successrate* gensuc*
foreach i in `r(varlist)' {
	replace `i' = `i'*100
	}
drop hpi lhpi
ren *_mw *

gen bartik_sq = MSAempCh_bartik_restr^2
lab var bartik_sq "Bartik$^{2}$"


//msa level regression
ren successrate successrate_t
ren successrate_w successrate_w_t
ren gensuc gensuc_t
ren gensuc2 gensuc2_t

local stub "t s660 young spy"
foreach x in `stub' {
	local s1 "`s1'successrate_`x' "
	}

di "`s1'"

lab var pctch_avgmw "Pct.\ Chg.\ Min.\ Wage (t)"
lab var f_pctch_avgmw "Pct.\ Chg.\ Min.\ Wage (t+1)"
lab var l_pctch_avgmw "Pct.\ Chg.\ Min.\ Wage (t-1)"
lab var MSAempCh_bartik_restr "Bartik Emp. Growth"

//////////////////////////////////////////////////////////////////////////
*success rate regressions
/////////////////////////////////////////////////////////////////////////

foreach x in `s1' {

	reghdfe `x' pctch_avgmw l_pctch_avgmw MSAempCh_bartik_restr, absorb(year geocode) cluster(geocode)
	gen sample`x' = e(sample)
	local sample`x'1 "`sample`x'1'sample`x' "

	egen sample`x'1 = rowmin(`sample`x'1')


		reghdfe `x' pctch_avgmw l_pctch_avgmw MSAempCh_bartik_restr  if sample`x'1 == 1, absorb(year geocode) cluster(geocode)
		lincom pctch_avgmw + l_pctch_avgmw
		local 2years = r(estimate)
		local p = round(2*ttail(r(df), abs(r(estimate)/r(se))), 0.001)
		
		local scalnum "Persistent `2years' Pvalue `p' "

		eststo `x'h1, add(`scalnum')
	}
}


foreach j in `stub' {
	local suc1 "`suc1'successrate_`j'h1 "
	}

di "`suc1'"

///////////////////////////////////////////////////////
*share of subprime borrowers
//////////////////////////////////////////////////////

use data/msa_subprimeshare_1999_2017.dta, clear
capture drop hpi lhpi
ren *_mw *
xtset geocode year 

gen l_sp = l.sp
replace sp = sp*100
replace d_sp = d_sp*100
replace d_sp = . if year == 1999 //1998 data not available 
sum sp d_sp


lab var pctch_avgmw "Pct.\ Chg.\ Min.\ Wage (t)"
lab var f_pctch_avgmw "Pct.\ Chg.\ Min.\ Wage (t+1)"
lab var l_pctch_avgmw "Pct.\ Chg.\ Min.\ Wage (t-1)"
lab var MSAempCh_bartik_restr "Bartik Emp. Growth"


//determine sample for subprime
reghdfe d_sp pctch_avgmw l_pctch_avgmw MSAempCh_bartik_restr, absorb(year geocode) cluster(geocode)
gen samplesp1 = e(sample)
	
	reghdfe d_sp pctch_avgmw l_pctch_avgmw  MSAempCh_bartik_restr if samplesp1 == 1, absorb(year geocode) cluster(geocode)
	lincom pctch_avgmw + l_pctch_avgmw
	local 2years = r(estimate)
	local p = round(2*ttail(r(df), abs(r(estimate)/r(se))), 0.001)
		
	local scalnum "Persistent `2years' Pvalue `p' "

	eststo sph181, add(`scalnum')


//////////////////////////////////////////////////////////////////
* combine success rate tables and subprime share regression results
//////////////////////////////////////////////////////////////////

#delimit; 

	esttab `suc1' sph181 using latex/Table7.tex, replace depvars l se(%4.3f) b(%4.3f) ar2(%4.3f) starlevels(* 0.1 ** 0.05 *** 0.01) compress nonotes sfmt(%4.3f) 
		scalars("Persistent Two-year MW Effect$^{\dagger}$" "Pvalue P-Value") keep(*pctch_avgmw *MSAempCh_bartik_restr /**hpi**/) order(pctch_avgmw Persistent Pvalue)
		msign(--) nom  collabels(none) nomtitles
		prehead("\begin{table}\centering" "\caption{Success in Credit Applications, the Subprime Share, and Minimum Wage Changes}" "\scalebox{0.85}" "{" "\label{success}" "\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}" 
		"\begin{tabular}{l*{6}{c}}" "\hline\hline ") 
		posthead("&\multicolumn{4}{c}{Success Rate }& \multicolumn{1}{c}{Change}\\" "\cline{2-5}" 
		" &\multicolumn{1}{c}{Total }&\multicolumn{1}{c}{Subprime}&\multicolumn{1}{c}{Young}&\multicolumn{1}{c}{Subprime} &\multicolumn{1}{c}{Subprime}\\"
		"                &\multicolumn{1}{c}{Sample}&\multicolumn{1}{c}{}&\multicolumn{1}{c}{}&\multicolumn{1}{c}{Young} &\multicolumn{1}{c}{Share}\\" "\hline" "\\") 
		prefoot("\hline") 
		postfoot("\hline\hline" "\end{tabular}" "}" "\parbox[1]{6.5in}{\footnotesize"
		"\textit{Notes:} The estimates are based on the baseline equation $ \Delta x^k_{i,t}=\alpha_i +\nu_t +\sum_{j=0}^{1} \beta(j) \Delta w_{i,t-j}+ \eta y_{i,t} + e_{i,t}, $"
		"where the dependent variable is the percent change in total debt balances for the borrower group indicated  at the top of each column.  The annual data cover 1999--2017. 
		 The estimates include location (CPI MSA) fixed effects as well as year effects.  The percent change in the minimum wage when a CPI MSA spans different states is calculated based 
		 on the average (population-weighted) minimum wage in each location and year as discussed in the text. $^{\dagger}$ 
		 Cumulative effect of the minimum wage change measured over two years (sum of contemporaneous and lagged effects).
		  Standard errors clustered by CPI MSA are in parentheses:  * p$<$0.10, ** p$<$0.05, *** p$<$0.01.}" "\end{table}") ;
	

#delimit cr
